@@ -5,9 +5,13 @@
 #ifndef AFFINITY_H
 #define AFFINITY_H
 
+#ifdef _OPENMP
+
 extern int affinity_getProcessorId();
 extern void affinity_pinProcess(int);
 extern void affinity_pinThread(int);
 extern void affinity_getmask(void);
 
+#endif /*_OPENMP*/
+
 #endif /*AFFINITY_H*/
